Index: wp-content/themes/twentyfourteen/inc/template-tags.php
===================================================================
--- wp-content/themes/twentyfourteen/inc/template-tags.php	(revision 25830)
+++ wp-content/themes/twentyfourteen/inc/template-tags.php	(working copy)
@@ -80,8 +80,12 @@
 		<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'twentyfourteen' ); ?></h1>
 		<div class="nav-links">
 			<?php
+			if ( is_attachment() ) :
+				previous_post_link( '%link', __( '<span class="meta-nav">Published In</span>%title', 'twentyfourteen' ) );
+			else :
 				previous_post_link( '%link', __( '<span class="meta-nav">Previous Post</span>%title', 'twentyfourteen' ) );
 				next_post_link( '%link', __( '<span class="meta-nav">Next Post</span>%title', 'twentyfourteen' ) );
+			endif;
 			?>
 		</div><!-- .nav-links -->
 	</nav><!-- .navigation -->
Index: wp-content/themes/twentyfourteen/style.css
===================================================================
--- wp-content/themes/twentyfourteen/style.css	(revision 25830)
+++ wp-content/themes/twentyfourteen/style.css	(working copy)
@@ -1732,6 +1732,10 @@
  * -----------------------------------------------------------------------------
  */
 
+.attachment .content-sidebar {
+	display: none;
+}
+
 .attachment .entry-content {
 	padding-top: 0;
 }
@@ -1739,6 +1743,7 @@
 .attachment footer.entry-meta {
 	text-transform: none;
 }
+
 .entry-attachment .attachment {
 	margin-bottom: 24px;
 }
@@ -2950,7 +2955,7 @@
 		margin-right: -168px;
 	}
 
-	.attachment .entry-content .attachment {
+	.attachment .entry-attachment .attachment {
 		margin-right: -168px;
 		margin-left: -168px;
 		max-width: 810px;

Index: wp-content/themes/twentyfourteen/functions.php
===================================================================
--- wp-content/themes/twentyfourteen/functions.php	(revision 25830)
+++ wp-content/themes/twentyfourteen/functions.php	(working copy)
@@ -118,14 +118,14 @@
 add_action( 'after_setup_theme', 'twentyfourteen_setup' );
 
 /**
  * Adjust content_width value for full-width and attachment templates.
  *
  * @since Twenty Fourteen 1.0
  *
  * @return void
  */
 function twentyfourteen_content_width() {
-	if ( is_attachment() )
+	if ( is_attachment() && wp_attachment_is_image() )
 		$GLOBALS['content_width'] = 810;
 }
 add_action( 'template_redirect', 'twentyfourteen_content_width' );
@@ -118,14 +118,14 @@
 
 /**
- * Adjust content_width value for full-width and attachment templates.
+ * Adjust content_width value for image attachment template.
  *
  * @since Twenty Fourteen 1.0